---
title: "AI for healthcare"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Recap of the previous lectures

To mitigate the **curse of dimensionality**, we use:

- **Expert** knowledge: high-quality features.

- Relevant **families** of functions: kernels, convolutional networks.

- Relevant **neighborhood** structures: graphs.

`\begin{center}`{=latex}

 \
Main challenge: $\BR{local}$ implementation $\Longrightarrow$ $\BR{global}$ understanding. \
\
Produce **guidelines** and **insights** for practitioners.
`\end{center}`{=latex}


## Large graphs are best understood as continuous objects `\cite{peyre2011numerical,heart_raw}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/6n-graf.pdf){height=3cm}

 \
**Simple** graph.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/knn_graph.png){height=3cm}

 \
Manifold **hypothesis**.

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/mesh.png){height=3cm}

 \
**Physical** manifold.

`\end{center}`{=latex}
::::
:::





## Long history in physics `\cite{solar_system,ideal_gas,nabizadeh2022covector}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/solar_system.png){height=3cm}

 \
The **Solar** system.

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/ideal_gas.png){height=3cm}

 \
The **ideal gas** model.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/fluid_simulation.png){height=3cm}

 \
**Fluid** simulation.

`\end{center}`{=latex}
::::
:::




## Remaining lectures

Lecture 5 -- From discrete graphs to **continuous spaces**:

- The Poincaré disk.
- Local metrics and geodesics.

Lecture 6 -- From discrete samples to **continuous distributions**:

- Duality: distributions and adversarial norms.
- Information geometry, kernels and optimal transport.

Lecture 7 -- **Hardware** bottlenecks:

- Registers, parallel cores and compilers.
- Current trends.

## References `\cite{ghys2006poincare,cannon1997hyperbolic,lee1997riemannian,geometric_data_analysis_feydy}`{=latex}

**Textbooks** and introductions -- in English:

- *Poincaré and his disk* -- Étienne Ghys, 2006.
- *Hyperbolic geometry* -- Cannon et al., 1997.
- *Riemannian geometry: an introduction to curvature* -- John M. Lee, 1997.
- *Geometric data analaysis, beyond convolutions* -- my PhD thesis, 2020.

**Lecture notes** available on my website -- in French:

- *Culture mathématique*.
- *Introduction à la géométrie riemannienne par l'étude des espaces de formes*.



# The Poincaré disk



## *Science and hypothesis* -- Henri Poincaré, 1902

::: columns
:::: {.column width=65%}

`\begin{center}`{=latex}

 \
 \
**The Non-Euclidean World.** -- **If** geometrical space
were a framework imposed on **each** of our representations considered **individually**, 
it would be **impossible** to represent to ourselves an image without this framework,
and we should be quite **unable** to change our geometry.

 \
 \
$\BR{But this is not the case;}$ **geometry is only the summary
of the laws by which these images succeed each other.**

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/poincare/triangles_intro.png){height=7cm}

`\end{center}`{=latex}
::::
:::



## *Science and hypothesis* -- Henri Poincaré, 1902

::: columns
:::: {.column width=65%}

`\begin{center}`{=latex}

 \
 \
There is nothing, therefore, to prevent us from imagining
a **series of representations**, similar in every way to our
ordinary representations, but succeeding one another according to 
laws which **differ** from those \
to which we are accustomed. 

 \
We may thus conceive that beings whose
education has taken place in a medium in which those
laws would be so different, might have 
$\BR{a very different geometry}$ \
from ours.

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/poincare/triangles_intro.png){height=7cm}

`\end{center}`{=latex}
::::
:::




## *Science and hypothesis* -- Henri Poincaré, 1902 `~~\cite{disk_temperature}`{=latex}


::: columns
:::: {.column width=65%}

 \
Suppose, for example, a world **enclosed in a large sphere** 
and subject to the following laws: \
 \

- The $\BR{temperature is not uniform;}$ \
  it is **greatest at the centre**, 
  and gradually decreases as we move towards the **circumference** of the sphere, 
  where it is **absolute zero**. \
  \
  The $\BR{law of this temperature is as follows:}$ \
  if $R$ be the radius of the sphere, 
  and $r$ the distance of the point considered from
  the centre, the absolute temperature will be **proportional**
  to $R^2 − r^2$. 

::::
:::: {.column width=35%}
`\begin{center}\vspace*{1.38cm}`{=latex}
![](images/poincare/Poincare_disk_1.png){height=5cm}

`\end{center}`{=latex}
::::
:::



## *Science and hypothesis* -- Henri Poincaré, 1902 `~~\cite{disk_temperature}`{=latex}


::: columns
:::: {.column width=65%}

 \
 \

- Further, I shall suppose that in this world
  **all bodies have the same coefficient of dilatation**, 
  so that the linear $\BR{dilatation}$ of any body is proportional to its absolute $\BR{temperature}$. \
  \
  \
  
- Finally, I shall assume that a body transported from one point to another of different tem-
  perature is **instantaneously** in thermal **equilibrium** with its new environment. 

 \
 \
 \

::::
:::: {.column width=35%}
`\begin{center}\vspace*{1.4cm}`{=latex}
![](images/poincare/Poincare_disk_1.png){height=5cm}

`\end{center}`{=latex}
::::
:::

 

## *Science and hypothesis* -- Henri Poincaré, 1902 `~~\cite{disk_temperature}`{=latex}


::: columns
:::: {.column width=65%}

`\begin{center}\vspace*{.15cm}`{=latex}

There is **nothing** in these hypotheses either **contradictory** or **unimaginable**. 
A moving object will become **smaller and smaller** as it approaches the
**circumference** of the sphere. \
 \

Let us observe, in the first place, that although from the point of view of **our** 
ordinary geometry this world is **finite**, 
$\BR{to its inhabitants it will appear infinite}$. \
 \

As they approach the surface of
the sphere they become **colder**, and at the same time
smaller and smaller. The steps they take are therefore
also **smaller** and smaller, so that they can never reach
the **boundary** of the sphere. 

`\end{center}`{=latex}

::::
:::: {.column width=35%}
`\begin{center}\vspace*{1.4cm}`{=latex}
![](images/poincare/Poincare_disk_1.png){height=5cm}

`\end{center}`{=latex}
::::
:::





## The Poincaré metric is locally a Euclidean metric


::: columns
:::: {.column width=65%}


With $x^2 + y^2 < 1$, we define:
$$\mathrm{d}\Big( (x,y) \rightarrow (x,y) + (\mathrm{d}x, \mathrm{d}y) \Big) 
~=~
2 \,\frac{ \sqrt{\mathrm{d}x^2 + \mathrm{d}y^2}}{1 - (x^2 + y^2)}$$

In other words:
$$\mathrm{d}^2\Big( (x,y) \rightarrow (x,y) + (\mathrm{d}x, \mathrm{d}y) \Big) 
~=~
4 \,\frac{ \mathrm{d}x^2 + \mathrm{d}y^2}{\big( 1 - (x^2 + y^2)\big)^2}$$

This **local** Euclidean metric is the $\BR{Riemannian}$ metric:
$$\| (\mathrm{d}x, \mathrm{d}y) \|_{(x,y)}^2
~=~
\big\langle\, (\mathrm{d}x, \mathrm{d}y)\,,\, 
g_{(x,y)}\,(\mathrm{d}x, \mathrm{d}y) \,\big\rangle
$$
$$
g_{(x,y)} ~=~ \begin{pmatrix}
4/\big( 1 - (x^2 + y^2)\big)^2 & 0 \\
0 & 4/\big( 1 - (x^2 + y^2)\big)^2
\end{pmatrix}
$$

::::
:::: {.column width=35%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/Riemannian_metric.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::


## Length of curve


::: columns
:::: {.column width=65%}

If $\gamma : [0,1] \rightarrow B(0,1)$ is a **smooth path**, we define:
$$\ell(\gamma)
~=~
\int_0^1 \|\dot{\gamma}(t)\|_{\gamma(t)} \,\mathrm{d}t$$

```{=latex}
For the \textbf{straight path} $\gamma(t) = (t, 0)$, we find:
\begin{align*}
\ell(\gamma)
~&=~
\int_0^1 \|(1, 0)\|_{(t,0)} \,\mathrm{d}t\\
&=~
\int_0^1 \frac{2}{1 - t^2} \,\mathrm{d}t \\
&=~
\int_0^1 \frac{2}{(1 + t)(1 - t)} \,\mathrm{d}t ~=~ +\infty
\end{align*}
```

The Poincaré disk is $\BR{a universe in a nutshell}$.

::::
:::: {.column width=35%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/Riemannian_length.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::


## Tissot's indicatrix `\cite{mercator_projection, mercator_tissot}`{=latex}

`\begin{center}\vspace*{-0.2cm}`{=latex}
![](images/poincare/mercator.png){width=100%}

Tissot's indicatrix at location $(x,y)$ is a **unit ball** for the local metric. \
This ellipsoid allows us to **depict distortions** in cartography \
and fully describes a **Riemannian metric** on the 2D map.

`\end{center}`{=latex}


## Equivalent descriptions of the Poincaré segment $(-1,+1)$

::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the segment $I$}, \textcolor{green!60!black}{the half-circle $J$} and \textcolor{blue!80!black}{the half-line $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x)\|_{(x)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2}}{1 - x^2}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}z)\|_{(x,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}z)\|_{(z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_segment_0.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::

## Equivalent descriptions of the Poincaré segment $(-1,+1)$

::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the segment $I$}, \textcolor{green!60!black}{the half-circle $J$} and \textcolor{blue!80!black}{the half-line $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x)\|_{(x)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2}}{1 - x^2}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}z)\|_{(x,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}z)\|_{(z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_segment.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::



## Equivalent descriptions of the Poincaré segment $(-1,+1)$

::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the segment $I$}, \textcolor{green!60!black}{the half-circle $J$} and \textcolor{blue!80!black}{the half-line $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x)\|_{(x)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2}}{1 - x^2}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}z)\|_{(x,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}z)\|_{(z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_segment_1.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::



## Equivalent descriptions of the Poincaré segment $(-1,+1)$

::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the segment $I$}, \textcolor{green!60!black}{the half-circle $J$} and \textcolor{blue!80!black}{the half-line $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x)\|_{(x)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2}}{1 - x^2}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}z)\|_{(x,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}z)\|_{(z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_segment_2.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::



## Equivalent descriptions of the Poincaré segment $(-1,+1)$

::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the segment $I$}, \textcolor{green!60!black}{the half-circle $J$} and \textcolor{blue!80!black}{the half-line $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x)\|_{(x)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2}}{1 - x^2}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}z)\|_{(x,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}z)\|_{(z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_segment_3.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::

## Equivalent descriptions of the Poincaré disk


::: columns
:::: {.column width=60%}

 \
Stereographic projections define bijections between \
`\textcolor{red!80!black}{the disk $I$}, \textcolor{green!60!black}{the hemisphere $J$} and \textcolor{blue!80!black}{the half-plane $H$}.`{=latex} \
 \
If we endow $I$ with the Poincaré metric:
$$\textcolor{red!80!black}{\|(\mathrm{d}x,\mathrm{d}y)\|_{(x,y)\in I} ~=~ 2\, \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2}}{1 - (x^2+y^2)}}~,$$
```{=latex}
then $J$ and $H$ are endowed with:
\begin{align*}
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}y,\mathrm{d}z)\|_{(x,y,z)\in J}} 
~&\textcolor{green!60!black}{=~ \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2+\mathrm{d}z^2}}{z}} \\
~\\
\textcolor{blue!80!black}{\|(\mathrm{d}y,\mathrm{d}z)\|_{(y,z) \in H}} 
~&
\textcolor{blue!80!black}{=~ \frac{\sqrt{\mathrm{d}y^2+\mathrm{d}z^2}}{z}}
\end{align*}
```

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/projections_disk.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::


## Tissot's indicatrix on the Poincaré disk, hemisphere and half-plane

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/tissot_disk.pdf){height=4cm}

$$\textcolor{red!80!black}{2\, \frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2}}{1 - (x^2+y^2)}}$$

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/tissot_sphere.pdf){height=4cm}

$$\textcolor{green!60!black}{\frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2+\mathrm{d}z^2}}{z}}$$

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/tissot_plane.pdf){height=4cm}

$$\textcolor{blue!80!black}{\frac{\sqrt{\mathrm{d}y^2+\mathrm{d}z^2}}{z}}$$

`\end{center}`{=latex}
::::
:::





## The discrete Poincaré grid

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/tissot_plane.pdf){height=5cm}

`\vspace*{-.35cm}`{=latex}
$$\textcolor{blue!80!black}{\frac{\sqrt{\mathrm{d}y^2+\mathrm{d}z^2}}{z}}$$

`\end{center}`{=latex}
::::
:::: {.column width=50%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/tissot_grid.pdf){height=5cm}

 \
Octave grid based on a dyadic tree.

`\end{center}`{=latex}
::::
:::


# Geodesics on the Poincaré disk

## Geodesics on the Poincaré grid

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/geodesic_grid_1.pdf){height=5cm}

`\vspace*{.25cm}`{=latex}
The `\textcolor{green!60!black}{green}`{=latex} and `\textcolor{red!80!black}{red}`{=latex} paths \
have the same length.

`\end{center}`{=latex}
::::
:::: {.column width=50%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/geodesic_grid_3.pdf){height=5cm}

`\vspace*{.25cm}`{=latex}
Going **up** is faster than \
travelling **sideways**.

`\end{center}`{=latex}
::::
:::



## Vertical geodesics on the Poincaré half-plane

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}
`\begin{center}\vspace*{0.25cm}`{=latex}

If the source and target points belong to \
the **vertical axis** $~~y = 0$, $~~$the shortest \
path is **straight**:
```{=latex}
\begin{align*}
\textcolor{red!80!black}{\ell\big(y(t),z(t)\big)}~
&=~ \int_0^1 
\frac{\sqrt{\dot{y}(t)^2 + \dot{z}(t)^2}}{z(t)}
\mathrm{d}t \\
&\leqslant~ \int_0^1 
\frac{\sqrt{\dot{z}(t)^2}}{z(t)}
\mathrm{d}t \\
&=~ \textcolor{green!60!black}{\ell\big( 0, z(t) \big)}~.
\end{align*}
```

`\end{center}`{=latex}
::::
:::: {.column width=40%}
`\begin{center}\vspace*{.5cm}`{=latex}
![](images/poincare/straight_plane.pdf){height=5cm}


`\end{center}`{=latex}
::::
:::


## Centers of the three Poincaré models

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}

 \
Using our stereographic projections, \
the North pole $(x,y,z) = (0,0,+1)$ \
of the $\textbf{\textcolor{green!60!black}{hemisphere}}$
corresponds to: \
 \

- the center $(x,y) = (0,0)$ of the $\textbf{\textcolor{red!80!black}{disk}}$, \
  \
- the point $~~(y,z) = (0, +2)~~$ \
  of the $\textbf{\textcolor{blue!80!black}{half-plane}}$.


::::
:::: {.column width=40%}
`\begin{center}\vspace*{-0.5cm}`{=latex}
![](images/poincare/projections_disk_meridian_0.pdf){height=7cm}


`\end{center}`{=latex}
::::
:::

## Geodesics on the Poincaré hemisphere

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}

The vertical axis in the $\textbf{\textcolor{blue!80!black}{half-plane}}$
is equivalent to the **"Greenwich meridian"** \
in the $\textbf{\textcolor{green!60!black}{hemisphere}}$. \
 \
Since the Poincaré metric:
$$
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}y,\mathrm{d}z)\|_{(x,y,z)\in J}
~=~ 
\frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2+\mathrm{d}z^2}}{z}} 
$$
is invariant by **rotations**: 
`\vspace*{-.3cm}`{=latex}
$$(x,y,z) \mapsto (\cos(\theta) \, x,  \sin(\theta)\,y, z)~,$$
`\vspace*{-.8cm}`{=latex}

all great circles that pass through the North pole are also **geodesic curves**.

::::
:::: {.column width=40%}
`\begin{center}\vspace*{-0.5cm}`{=latex}
![](images/poincare/projections_disk_meridian.pdf){height=7cm}


`\end{center}`{=latex}
::::
:::


## Geodesics on the Poincaré hemisphere

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}

The vertical axis in the $\textbf{\textcolor{blue!80!black}{half-plane}}$
is equivalent to the **"Greenwich meridian"** \
in the $\textbf{\textcolor{green!60!black}{hemisphere}}$. \
 \
Since the Poincaré metric:
$$
\textcolor{green!60!black}{\|(\mathrm{d}x,\mathrm{d}y,\mathrm{d}z)\|_{(x,y,z)\in J}
~=~ 
\frac{\sqrt{\mathrm{d}x^2+\mathrm{d}y^2+\mathrm{d}z^2}}{z}} 
$$
is invariant by **rotations**: 
`\vspace*{-.3cm}`{=latex}
$$(x,y,z) \mapsto (\cos(\theta) \, x,  \sin(\theta)\,y, z)~,$$
`\vspace*{-.8cm}`{=latex}

all great circles that pass through the North pole are also **geodesic curves**.

::::
:::: {.column width=40%}
`\begin{center}\vspace*{-0.5cm}`{=latex}
![](images/poincare/projections_disk.pdf){height=7cm}


`\end{center}`{=latex}
::::
:::





## Meridians on the three Poincaré models

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/meridians_disk.pdf){height=4cm}

 \
$\textcolor{red!80!black}{\text{Diameters.}}$

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/meridians_sphere.pdf){height=4cm}

 \
$\textcolor{green!60!black}{\text{Meridians.}}$

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/meridians_plane.pdf){height=4cm}

 \
$\textcolor{blue!80!black}{\text{Half-circles that pass}}$ \
$\textcolor{blue!80!black}{\text{through}~~(y,z) = (0, +2)~.}$

`\end{center}`{=latex}
::::
:::





## Geodesics on the Poincaré half-plane

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=50%}

**Half-circles** that are perpendicular to the horizontal
axis **are all geodesics**. \
\
This is because the Poincaré metric:
$$
\textcolor{blue!80!black}{\|(\mathrm{d}y,\mathrm{d}z)\|_{(y,z) \in H}
~=~ 
\frac{\sqrt{\mathrm{d}y^2+\mathrm{d}z^2}}{z}}
$$
is invariant by **horizontal translations**: 
`\vspace*{-.3cm}`{=latex}
$$(y,z) \mapsto (y+\Delta y, z)$$
and **scalings** with a positive constant $a > 0$:
`\vspace*{-.3cm}`{=latex}
$$(y,z) \mapsto (ay, az)~.$$

::::
:::: {.column width=40%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/translation_plane.pdf){height=5cm}


`\end{center}`{=latex}
::::
:::






## Geodesics on the Poincaré grid, half-plane and disk

`\vspace*{.5cm}`{=latex}

::: columns

:::: {.column width=32%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/geodesic_grid_3.pdf){height=4cm}

 \
Up-and-down paths.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/geodesics_plane.pdf){height=4cm}

 \
$\textcolor{blue!80!black}{\text{Half-circles and}}$ \
$\textcolor{blue!80!black}{\text{vertical lines}.}$

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}\vspace*{0cm}`{=latex}
![](images/poincare/geodesics_disk.pdf){height=4cm}

 \
$\textcolor{red!80!black}{\text{Orthogonal circles and}}$ \
$\textcolor{red!80!black}{\text{diameters}.}$

`\end{center}`{=latex}
::::
:::


## A continuous tree

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/LW436-MC-Escher-Circle-Limit-IV-19601.jpg){height=5cm}

 \
Circle Limit IV by **M.C. Escher**:\
a $\BR{regular}$ tiling of the Poincaré disk.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/poincare/SL2_Z_u,s,-id_rayon8.dot-neato-point.pdf){height=5cm}

 \
The Cayley graph of $\text{SL}_\text{2}(\mathbb{Z})$ \
is to the **Poincaré** disk what a $\BR{regular grid}$ is to the **Euclidean** plane.

`\end{center}`{=latex}
::::
:::


## Recap on the Poincaré disk


We should **remember** that:

- A **Riemannian** metric is a smooth field of Euclidean norms. \
  It is equivalent to **Tissot's indicatrix** in cartography.

- **Convenient** way of defining arbitrary geometries:\
  the Poincaré disk is a continuous tree.

- **Changes of coordinates** are key to eloquent proofs. \
  Don't get stuck on one parameterization.

- $\BR{Discrete}$ $\leftrightarrow$ $\BR{Continuous}$ analogies go both ways.


# Riemannian geometry, in practice

## A convenient way of working with surfaces

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/torus_3D_equators.png){height=5cm}

 \
As a surface **embedded in 3D**.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/torus_2D_equators.pdf){height=5cm}

 \
The torus as a **flat 2D square**.

`\end{center}`{=latex}
::::
:::


## A convenient way of working with surfaces

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/Torus3D.png){height=5cm}

 \
**Geodesics** on the donut.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/Torus2D.pdf){height=5cm}

 \
The torus as a $\BR{curved}$ **2D square**.

`\end{center}`{=latex}
::::
:::


## Mathematical objects  `\cite{arsigny2006log,kuhnel2019differential}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=55%}
`\begin{center}`{=latex}
![](images/riemann/covariances.pdf){height=3.6cm}

 \
**Covariance matrices:** geodesics for the 
`\textcolor{red!60!black}{Euclidean}`{=latex},
`\textcolor{green!80!black}{affine-invariant}`{=latex}
and \
`\textcolor{blue!60!black}{log-Euclidean}`{=latex} metrics.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/rotations.png){height=3.6cm}

 \
**3D rotations**: geodesics for \
the Lie group structure.

`\end{center}`{=latex}
::::
:::


## Probability distributions -- see Lecture 6!  `\cite{peyre}`{=latex}


::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/Gaussian_wasserstein.png){height=5.5cm}

 \
Gaussians + **Wasserstein** metric \
$=~~$ $\BR{Euclidean}$.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/Gaussian_fisher_rao.png){height=5.5cm}

 \
Gaussians + relative **entropy** \
$=~~$ $\BR{Poincaré}$.

`\end{center}`{=latex}
::::
:::


## Shape metrics -- remember Lecture 1!

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/vue_xi.png){height=5.5cm}

 \
The **plane** of triangle shapes.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/vue_cavaliere.png){height=5.5cm}

 \
The $\BR{sphere}$ of triangle shapes.

`\end{center}`{=latex}
::::
:::


## Shape metrics `\cite{kilian2007geometric}`{=latex}


`\begin{center}`{=latex}

![](images/elastic/kilian.jpg){height=80%}

Geodesics in spaces of elephants and skeletons.

`\end{center}`{=latex}

## Shape metrics `\cite{von2016optimized}`{=latex}


`\begin{center}`{=latex}

![](images/elastic/barycenter.jpg){height=80%}

Barycentric interpolation in a space of hands.

`\end{center}`{=latex}



## Network architectures are "projections" from parameter space to function space

`\begin{center}`{=latex}

![](images/riemann/projections_neural_networks.pdf){height=5cm}

$~~~~~~~~~~$ $\BR{Standard}$ gradient descent on the parameters \
$\Longleftrightarrow~~$
$\BR{Riemannian}$ gradient descent on the network. \
Core idea behind the **natural gradient**, neural **tangent kernels**, \
(Wasserstein) **gradient flows**...

`\end{center}`{=latex}


## Graph and point cloud embeddings `~~\cite{sala2018representation,nickel2017poincare}`{=latex}

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/tree_embedding.png){height=5cm}

Embedding a **tree** in the Poincaré disk.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/riemann/wordnet_embedding.png){height=5cm}

WordNet **mammals** subtree

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}
UMAP (Uniform **Manifold** Approximation and Projections) \
also works with Riemannian metrics.
`\end{center}`{=latex}

## The geodesic equation -- Hamiltonian form

If $H(q,p)~=~ \tfrac{1}{2} \langle\, p \,,\, g_{q}^{-1} p\,\rangle$ denotes the
**Hamiltonian** for the Riemannian metric $g_q$, \
we can show that **paths** $q(t)$ that **minimize length** locally
and travel at **constant speed** follow a
$\BR{coupled Ordinary Differential Equation}$ with a 
**momentum** vector $p(t)$:
$$
\begin{cases}
    \dot{q}(t) ~=~
    +\tfrac{\partial H}{\partial p}(q(t),p(t)) 
    &\quad\text{\textbf{follow} the velocity $v(t) = g_{q(t)}^{-1}p(t)$.}\\
    \dot{p}(t) ~=~
    -\tfrac{\partial H}{\partial q}(q(t),p(t))
    &\quad\text{\textbf{steer} the momentum to stay on a geodesic path.}
\end{cases}
$$

**Geodesic paths** are fully determined by:

- the starting $\BR{position}$ $q(t=0)$,
- the starting $\BR{momentum}$ $p(t=0)$ $\Longleftrightarrow$ the $\BR{velocity}$
$\dot{q}(t=0) = g_{q(t=0)} p(t=0)$.


## The exponential map `~~\cite{exponential_sphere,exponential_earth}`{=latex}


::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/riemann/exponential_1d.jpg){height=3.5cm}

From the 1D line \
to the **circle**.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/riemann/Exponential_map_of_the_sphere.pdf){height=3.5cm}

From the 2D plane \
to the **sphere**.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/riemann/Azimuthal_Equidistant_N90.jpeg){height=3.5cm}

Azimuthal equidistant \
projection.

`\end{center}`{=latex}
::::
:::



`\begin{center}`{=latex}

 \
$\exp_{q_0}(p_0)$ denotes the **solution** $q(t=1)$ of the geodesic equation \
with **initial condition** $q(t=0) = q_0$, $p(t=0)=p_0$.
`\end{center}`{=latex}

## Computing geodesics from $A$ to $B$ -- three main scenarios


**1. The metric has a lot of structure -- $\BR{closed formulas}$:**

  - Just like the Poincaré disk: simple example + symmetries.
  - Riemannian **metric** $~~\Longleftrightarrow~~$ Relevant **kernel**.\

**2. The $\BR{metric}$ $g_x$ is simple -- path shortening:**

  - Discretize the path energy $~~\ell^2(\gamma) \simeq \tfrac{1}{\text{N}}\sum_{i=1}^\text{N} \text{N}^2 \, \|\gamma(i/\text{N}) - \gamma((i-1)/\text{N}) \|^2_{\gamma(i/\text{N})}$.
  - "Mean curvature flow": gradient descent with respect to the snapshot positions.

**3. The $\BR{cometric}$ $K_q = (g_q)^{-1}$ is simple -- geodesic shooting:**

  - **Implement** the exponential $(q_0,p_0) \mapsto \exp_{q_0}(p_0)$ by integrating the Hamilton ODE.
  - **Solve** the inverse problem $p_0 \mapsto \exp_{A}(p_0) \simeq B$ with an optimizer or a network.

## Conclusion

**Riemannian metrics** provide:

- Expressive **vocabulary**: trees, balls, shapes and probability distributions.

- Complete **toolbox**: local metric $\longrightarrow$ geodesics, exponentials and barycenters.

- Appealing **message**: \
  $~~~~~~~~~~~\BR{simple paths on a curved space}$ $>$ **complex paths on a flat space.**


`\begin{center}`{=latex}
This framework is the cornerstone of several applied fields, \
and provides an `\BR{inspiring}`{=latex} outlook in many other settings. \
\
$\Longrightarrow~~~$ **Lab session** with GeomStats. $~~~\Longleftarrow$
`\end{center}`{=latex}

# References

